@@ -6,7 +6,7 @@ export grep="/usr/bin/grep"
 export gmake="/usr/bin/make"
 export gnumake="/usr/bin/make"
 export make="/usr/bin/make"
-export python="python3.11"
+export python="/usr/bin/python3.13"
 export sed="/usr/bin/sed"
 export libtool="/usr/bin/libtool"
 export libtoolize="/usr/bin/libtoolize"
